@@ -29,6 +29,7 @@ struct duo_config {
     char *cafile;
     char *http_proxy;
     char *groups[MAX_GROUPS];
+    char gecos_delim;
     int  groups_cnt;
     int  groups_mode;
     int  failmode;  /* Duo failure handling: DUO_FAIL_* */
@@ -41,8 +42,8 @@ struct duo_config {
     int  local_ip_fallback;
     int  https_timeout;
     int  send_gecos;
-    int  gecos_parsed;
     int  fips_mode;
+    int  gecos_username_pos;
 };
 
 void duo_config_default(struct duo_config *cfg);
